Method: Aws::AppMesh::Types::ListRoutesInput#limit

Defined in:
lib/aws-sdk-appmesh/types.rb

#limitInteger

The maximum number of results returned by ListRoutes in paginated output. When you use this parameter, ListRoutes returns only limit results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListRoutes request with the returned nextToken value. This value can be between 1 and 100. If you don’t use this parameter, ListRoutes returns up to 100 results and a nextToken value if applicable.

Returns:

  • (Integer)


2882
2883
2884
2885
2886
2887
2888
2889
2890
# File 'lib/aws-sdk-appmesh/types.rb', line 2882

class ListRoutesInput < Struct.new(
  :limit,
  :mesh_name,
  :mesh_owner,
  :next_token,
  :virtual_router_name)
  SENSITIVE = []
  include Aws::Structure
end