Class: Aws::AppMesh::Types::ListVirtualNodesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppMesh::Types::ListVirtualNodesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appmesh/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of results returned by
ListVirtualNodesin paginated output. -
#mesh_name ⇒ String
The name of the service mesh to list virtual nodes in.
-
#mesh_owner ⇒ String
The Amazon Web Services IAM account ID of the service mesh owner.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedListVirtualNodesrequest wherelimitwas used and the results exceeded the value of that parameter.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of results returned by ListVirtualNodes in
paginated output. When you use this parameter, ListVirtualNodes
returns only limit results in a single page along with a
nextToken response element. You can see the remaining results of
the initial request by sending another ListVirtualNodes request
with the returned nextToken value. This value can be between 1 and
100. If you don't use this parameter, ListVirtualNodes returns up
to 100 results and a nextToken value if applicable.
3085 3086 3087 3088 3089 3090 3091 3092 |
# File 'lib/aws-sdk-appmesh/types.rb', line 3085 class ListVirtualNodesInput < Struct.new( :limit, :mesh_name, :mesh_owner, :next_token) SENSITIVE = [] include Aws::Structure end |
#mesh_name ⇒ String
The name of the service mesh to list virtual nodes in.
3085 3086 3087 3088 3089 3090 3091 3092 |
# File 'lib/aws-sdk-appmesh/types.rb', line 3085 class ListVirtualNodesInput < Struct.new( :limit, :mesh_name, :mesh_owner, :next_token) SENSITIVE = [] include Aws::Structure end |
#mesh_owner ⇒ String
The Amazon Web Services IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes.
3085 3086 3087 3088 3089 3090 3091 3092 |
# File 'lib/aws-sdk-appmesh/types.rb', line 3085 class ListVirtualNodesInput < Struct.new( :limit, :mesh_name, :mesh_owner, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated
ListVirtualNodes request where limit was used and the results
exceeded the value of that parameter. Pagination continues from the
end of the previous results that returned the nextToken value.
3085 3086 3087 3088 3089 3090 3091 3092 |
# File 'lib/aws-sdk-appmesh/types.rb', line 3085 class ListVirtualNodesInput < Struct.new( :limit, :mesh_name, :mesh_owner, :next_token) SENSITIVE = [] include Aws::Structure end |