Class: Aws::AppMesh::Types::ListenerTlsSdsCertificate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appmesh/types.rb

Overview

An object that represents the listener’s Secret Discovery Service certificate. The proxy must be configured with a local SDS provider via a Unix Domain Socket. See App Mesh [TLS documentation] for more info.

[1]: docs.aws.amazon.com/app-mesh/latest/userguide/tls.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#secret_nameString

A reference to an object that represents the name of the secret requested from the Secret Discovery Service provider representing Transport Layer Security (TLS) materials like a certificate or certificate chain.

Returns:

  • (String)


3485
3486
3487
3488
3489
# File 'lib/aws-sdk-appmesh/types.rb', line 3485

class ListenerTlsSdsCertificate < Struct.new(
  :secret_name)
  SENSITIVE = []
  include Aws::Structure
end