Class: Aws::AppMesh::Types::VirtualGatewayHealthCheckPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appmesh/types.rb

Overview

An object that represents the health check policy for a virtual gateway’s listener.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#healthy_thresholdInteger

The number of consecutive successful health checks that must occur before declaring the listener healthy.



5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
# File 'lib/aws-sdk-appmesh/types.rb', line 5165

class VirtualGatewayHealthCheckPolicy < Struct.new(
  :healthy_threshold,
  :interval_millis,
  :path,
  :port,
  :protocol,
  :timeout_millis,
  :unhealthy_threshold)
  SENSITIVE = []
  include Aws::Structure
end

#interval_millisInteger

The time period in milliseconds between each health check execution.



5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
# File 'lib/aws-sdk-appmesh/types.rb', line 5165

class VirtualGatewayHealthCheckPolicy < Struct.new(
  :healthy_threshold,
  :interval_millis,
  :path,
  :port,
  :protocol,
  :timeout_millis,
  :unhealthy_threshold)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The destination path for the health check request. This value is only used if the specified protocol is HTTP or HTTP/2. For any other protocol, this value is ignored.



5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
# File 'lib/aws-sdk-appmesh/types.rb', line 5165

class VirtualGatewayHealthCheckPolicy < Struct.new(
  :healthy_threshold,
  :interval_millis,
  :path,
  :port,
  :protocol,
  :timeout_millis,
  :unhealthy_threshold)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The destination port for the health check request. This port must match the port defined in the PortMapping for the listener.



5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
# File 'lib/aws-sdk-appmesh/types.rb', line 5165

class VirtualGatewayHealthCheckPolicy < Struct.new(
  :healthy_threshold,
  :interval_millis,
  :path,
  :port,
  :protocol,
  :timeout_millis,
  :unhealthy_threshold)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol for the health check request. If you specify grpc, then your service must conform to the [GRPC Health Checking Protocol][1].

[1]: github.com/grpc/grpc/blob/master/doc/health-checking.md



5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
# File 'lib/aws-sdk-appmesh/types.rb', line 5165

class VirtualGatewayHealthCheckPolicy < Struct.new(
  :healthy_threshold,
  :interval_millis,
  :path,
  :port,
  :protocol,
  :timeout_millis,
  :unhealthy_threshold)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_millisInteger

The amount of time to wait when receiving a response from the health check, in milliseconds.



5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
# File 'lib/aws-sdk-appmesh/types.rb', line 5165

class VirtualGatewayHealthCheckPolicy < Struct.new(
  :healthy_threshold,
  :interval_millis,
  :path,
  :port,
  :protocol,
  :timeout_millis,
  :unhealthy_threshold)
  SENSITIVE = []
  include Aws::Structure
end

#unhealthy_thresholdInteger

The number of consecutive failed health checks that must occur before declaring a virtual gateway unhealthy.



5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
# File 'lib/aws-sdk-appmesh/types.rb', line 5165

class VirtualGatewayHealthCheckPolicy < Struct.new(
  :healthy_threshold,
  :interval_millis,
  :path,
  :port,
  :protocol,
  :timeout_millis,
  :unhealthy_threshold)
  SENSITIVE = []
  include Aws::Structure
end