Method: Aws::AppMesh::Types::OutlierDetection#max_ejection_percent
- Defined in:
- lib/aws-sdk-appmesh/types.rb
#max_ejection_percent ⇒ Integer
Maximum percentage of hosts in load balancing pool for upstream service that can be ejected. Will eject at least one host regardless of the value.
3786 3787 3788 3789 3790 3791 3792 3793 |
# File 'lib/aws-sdk-appmesh/types.rb', line 3786 class OutlierDetection < Struct.new( :base_ejection_duration, :interval, :max_ejection_percent, :max_server_errors) SENSITIVE = [] include Aws::Structure end |